@@ -1,5 +1,4 @@
-/* games-score.c 
- *
+/*
  * Copyright (C) 2005 Callum McKenzie
  *
  * This library is free software; you can redistribute it and/or
@@ -18,9 +17,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* We don't make it a proper object, basically to reduce overhead (system
-   memory and programmers time) */
-
 #include <config.h>
 
 #include "games-score.h"
@@ -29,11 +25,19 @@ GamesScore *
 games_score_new (void)
 {
   GamesScore *newscore;
+  const gchar* name;
 
   newscore = g_slice_new0 (GamesScore);
   newscore->time = time (NULL);
   /* FIXME: We don't handle the "Unknown" case. */
-  newscore->name = g_strdup (g_get_real_name ());
+  name = g_get_real_name ();
+  if (name[0] == '\0' || g_utf8_validate (name, -1, NULL) != TRUE) {
+    name = g_get_user_name ();
+    if (g_utf8_validate (name, -1, NULL) != TRUE) {
+      name = "";
+    }
+  }
+  newscore->name = g_strdup (name);
 
   return newscore;
 }
@@ -53,9 +57,7 @@ games_score_dup (GamesScore * orig)
 void
 games_score_destroy (GamesScore * score)
 {
-  if (score->name)
-    g_free (score->name);
-
+  g_free (score->name);
   g_slice_free (GamesScore, score);
 }
 
